struct DebugOnce<F>(Cell<Option<F>>);Expand description
Wraps an FnOnce formatting closure in a type that implements fmt::Debug by calling the
closure, allowing the *_with builder methods to forward to their &dyn fmt::Debug
counterparts.
By doing this, the builder logic is monomorphized only once and not for every closure type (see #149745).
Formatting a DebugOnce consumes the closure, so attempting to format it more than once
panics. This never happens because the debug builders format each value exactly once.
Tuple Fields
0: Cell<Option<F>>Trait Implementations